measuretools.get_first_measure_in_improper_parentage_of_component
=================================================================

.. autofunction:: abjad.tools.measuretools.get_first_measure_in_improper_parentage_of_component
